pub struct History {
pub rid: Option<String>,
pub messages: Vec<Message>,
pub active_start: usize,
pub config: Value,
pub selected_character: Option<String>,
pub revision: u64,
}Expand description
Full state snapshot.
Fields
rid: Option<String>messages: Vec<Message>active_start: usizeIndex of the first message that is still in the active prompt context.
Normal push/handshake snapshots contain only active context and leave this at zero. Bounded log/history responses may include durable archive scrollback before this index; those messages are useful for humans but are no longer part of the model’s active conversation context.
config: Valueselected_character: Option<String>revision: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for History
impl<'de> Deserialize<'de> for History
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more